pub struct FulfillmentOrder {
Show 16 fields pub seller_fulfillment_order_id: String, pub marketplace_id: String, pub displayable_order_id: String, pub displayable_order_date: String, pub displayable_order_comment: String, pub shipping_speed_category: ShippingSpeedCategory, pub delivery_window: Option<Box<DeliveryWindow>>, pub destination_address: Box<Address>, pub fulfillment_action: Option<FulfillmentAction>, pub fulfillment_policy: Option<FulfillmentPolicy>, pub cod_settings: Option<Box<CodSettings>>, pub received_date: String, pub fulfillment_order_status: FulfillmentOrderStatus, pub status_updated_date: String, pub notification_emails: Option<Vec<String>>, pub feature_constraints: Option<Vec<FeatureSettings>>,
}
FulfillmentOrder : General information about a fulfillment order, including its status.

Fields

seller_fulfillment_order_id: String

The fulfillment order identifier submitted with the createFulfillmentOrder operation.

marketplace_id: String

The identifier for the marketplace the fulfillment order is placed against.

displayable_order_id: String

A fulfillment order identifier submitted with the createFulfillmentOrder operation. Displays as the order identifier in recipient-facing materials such as the packing slip.

displayable_order_date: Stringdisplayable_order_comment: String

A text block submitted with the createFulfillmentOrder operation. Displays in recipient-facing materials such as the packing slip.

shipping_speed_category: ShippingSpeedCategorydelivery_window: Option<Box<DeliveryWindow>>destination_address: Box<Address>fulfillment_action: Option<FulfillmentAction>fulfillment_policy: Option<FulfillmentPolicy>cod_settings: Option<Box<CodSettings>>received_date: Stringfulfillment_order_status: FulfillmentOrderStatusstatus_updated_date: Stringnotification_emails: Option<Vec<String>>

A list of email addresses that the seller provides that are used by Amazon to send ship-complete notifications to recipients on behalf of the seller.

feature_constraints: Option<Vec<FeatureSettings>>

A list of features and their fulfillment policies to apply to the order.

Implementations

General information about a fulfillment order, including its status.